@@ -27,7 +27,7 @@ except ImportError as e:
     VECTORBT_AVAILABLE = False
     vbt = None
     logger = logging.getLogger(__name__)
-    logger.warning(f"VectorBT not available: {e}")
+    logger.info(f"VectorBT not available: {e}")
 
 from ..core.signal_extractor import SignalType, TradingSignal
 from ..core.base_signal_extractor import BaseSignalExtractor
